@@ -106,6 +106,7 @@ def _mqtt_on_message(
     if not _mac_address_valid(switchbot_mac_address):
         _LOGGER.warning("invalid mac address %s", switchbot_mac_address)
         return
+    # https://www.home-assistant.io/integrations/switch.mqtt/#payload_off
     if message.payload.lower() == b"on":
         action = _SwitchbotAction.ON
     elif message.payload.lower() == b"off":
@@ -116,6 +117,27 @@ def _mqtt_on_message(
     _send_command(switchbot_mac_address=switchbot_mac_address, action=action)
 
 
+def _run(
+    mqtt_host: str,
+    mqtt_port: int,
+    mqtt_username: typing.Optional[str],
+    mqtt_password: typing.Optional[str],
+) -> None:
+    # https://pypi.org/project/paho-mqtt/
+    mqtt_client = paho.mqtt.client.Client()
+    mqtt_client.on_connect = _mqtt_on_connect
+    mqtt_client.on_message = _mqtt_on_message
+    _LOGGER.info(
+        "connecting to MQTT broker %s:%d", mqtt_host, mqtt_port,
+    )
+    if mqtt_username:
+        mqtt_client.username_pw_set(username=mqtt_username, password=mqtt_password)
+    elif mqtt_password:
+        raise ValueError("Missing MQTT username")
+    mqtt_client.connect(host=mqtt_host, port=mqtt_port)
+    mqtt_client.loop_forever()
+
+
 def _main() -> None:
     logging.basicConfig(
         level=logging.DEBUG,
@@ -123,18 +145,17 @@ def _main() -> None:
         datefmt="%Y-%m-%dT%H:%M:%S%z",
     )
     argparser = argparse.ArgumentParser(
-        "MQTT client controlling SwitchBot button automators, "
+        description="MQTT client controlling SwitchBot button automators, "
         "compatible with home-assistant.io's MQTT Switch platform"
     )
     argparser.add_argument("--mqtt-host", type=str, required=True)
     argparser.add_argument("--mqtt-port", type=int, default=1883)
+    argparser.add_argument("--mqtt-username", type=str)
+    argparser.add_argument("--mqtt-password", type=str)
     args = argparser.parse_args()
-    # https://pypi.org/project/paho-mqtt/
-    mqtt_client = paho.mqtt.client.Client()
-    mqtt_client.on_connect = _mqtt_on_connect
-    mqtt_client.on_message = _mqtt_on_message
-    _LOGGER.info(
-        "connecting to MQTT broker %s:%d", args.mqtt_host, args.mqtt_port,
+    _run(
+        mqtt_host=args.mqtt_host,
+        mqtt_port=args.mqtt_port,
+        mqtt_username=args.mqtt_username,
+        mqtt_password=args.mqtt_password,
     )
-    mqtt_client.connect(host=args.mqtt_host, port=args.mqtt_port)
-    mqtt_client.loop_forever()
